@@ -2,11 +2,11 @@
 # coding: utf-8
 
 from typing import List, Any
-from dsFramework.base.common import ZIDS_Object
+from dsframework.base.common import ZIDS_Object
 
-from dsFramework.base.pipeline.preprocessor import ZIDS_Preprocessor
-from generatedPipelineDir.schema.inputs import generatedProjectNameInputs
-from generatedPipelineDir.artifacts.shared_artifacts import generatedProjectNameSharedArtifacts
+from dsframework.base.pipeline.preprocessor import ZIDS_Preprocessor
+from pipeline.schema.inputs import generatedProjectNameInputs
+from pipeline.artifacts.shared_artifacts import generatedProjectNameSharedArtifacts
 
 
 class generatedClass(ZIDS_Preprocessor):
