@@ -2,7 +2,7 @@
 # coding: utf-8
 
 from typing import Any
-from dsFramework.base.common import ZIDS_Object
+from dsframework.base.common import ZIDS_Object
 
 class ZIDS_Predictable(ZIDS_Object):
 
